#
# spec file for package dump
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dump
Version:        0.4b49
Release:        1.1
Summary:        Programs for backing up and restoring ext2/3/4 filesystems
License:        BSD-3-Clause
Group:          Productivity/Archiving/Backup
URL:            http://dump.sourceforge.net
Source0:        http://sourceforge.net/projects/%{name}/files/%{name}/%{version}/%{name}-%{version}.tar.gz
Source1:        ermt.1.in
# PATCH-FIX-SUSE dump-0.4b46-pathnames.patch svalx@svalx.net -- pathnames and
# symlinks configuration for dump and restore
Patch0:         %{name}-0.4b46-pathnames.patch
# PATCH-FIX-UPSTREAM dump-0.4b46-rmt-ermt.patch svalx@svalx.net -- Independent rmt and
# ermt build, change its locations to _bindir
Patch1:         %{name}-0.4b46-rmt-ermt.patch
Patch3:         %{name}-0.4b43-include.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  e2fsprogs-devel
BuildRequires:  libbz2-devel
BuildRequires:  libselinux-devel
BuildRequires:  libtool
BuildRequires:  lzo-devel
BuildRequires:  openssl-devel
BuildRequires:  readline-devel
BuildRequires:  sqlite3-devel
BuildRequires:  zlib-devel
Recommends:     %{name}-rmt = %{version}
Recommends:     mt

%description
The dump package contains both dump and restore.  Dump examines files
in a file system, determines which ones need to be backed up, and
copies those files to a specified disk, tape, or other storage medium.
The restore command performs the inverse function of dump. It can
restore a full backup of a file system.

%package	rmt
Summary:        Provides certain programs with access to remote tape devices
Group:          Productivity/Archiving/Backup
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       rmt

%description	rmt
The rmt utility provides remote access to tape devices for programs
like dump (a filesystem backup program), restore (a program for
restoring files from a backup), tar (an archiving program) and cpio.

%prep
%setup -q
cp %{SOURCE1} rmt/
%autopatch -p1

%build
autoreconf -fiv
export CFLAGS="%{optflags} -fcommon"
%configure \
  --disable-silent-rules \
  --enable-sqlite \
  --enable-ermt \
  --enable-rmt=no \
  --with-rmtpath=%{_bindir}
%make_build

%install
%make_install
mv examples/encrypted_rmt .
# Alternatives system
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -sf %{_sysconfdir}/alternatives/rmt %{buildroot}%{_bindir}/rmt
ln -sf %{_sysconfdir}/alternatives/rmt.1%{ext_man} %{buildroot}%{_mandir}/man1/rmt.1%{ext_man}

%post rmt
%{_sbindir}/update-alternatives --force \
    --install %{_bindir}/rmt rmt %{_bindir}/ermt 20 \
    --slave %{_mandir}/man1/rmt.1%{ext_man} rmt.1%{ext_man} %{_mandir}/man1/ermt.1%{ext_man}

%postun rmt
if [ ! -f %{_bindir}/ermt ] ; then
   "%{_sbindir}/update-alternatives" --remove rmt %{_bindir}/ermt
fi

%files
%{_sbindir}/dump
%{_sbindir}/restore
%{_mandir}/man8/dump.8%{?ext_man}
%{_mandir}/man8/restore.8%{?ext_man}
%license COPYING
%doc NEWS KNOWNBUGS MAINTAINERS README REPORTING-BUGS
%doc AUTHORS TODO dump.lsm examples

%files rmt
%ghost %{_bindir}/rmt
%{_bindir}/ermt
%ghost %{_mandir}/man1/rmt.1%{ext_man}
%{_mandir}/man1/ermt.1%{?ext_man}
%ghost %{_sysconfdir}/alternatives/rmt
%ghost %{_sysconfdir}/alternatives/rmt.1%{ext_man}
%doc encrypted_rmt/README

%changelog
* Tue Dec 17 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 0.4b49:
  * Reworking of regression tests and test harness
  * Import some patches from the Debian package.
  * restore -N should never change the fs. Fixes #154
  * Support outputting list of files from restore -t with '\0' separator
    (Patch from debian bug 703564 by Heiko Schlittermann)
  * Fix reading of QFA file when listing tape.
  * Support restoring to filesystems with a blocksize that isn't a multiple
    of TP_BSIZE (debian bug 995992). This is a different fix to the one
    currently in debian. The advantage of using a common multiple, if
    available, is that every FS block will only be written to once.
    Fixed an issue where the alignment between blocksize and writing pos
    becomes misaligned when a sparse hole doesn't occupy a full fs block
    (happens when restoring to a FS with a different, larger blocksize than
    the one the dump was taken on.
  * Numerous other minor patches from the Debian package
  * Don't read off end of buffer when restoring symlinks
  * Fix some weirdness around dumping a subdirectory. Do not include the
    inodes for all of the items in the subdirectories - which then give a
    restore error "inode not found on tape"
  * Fix EA problem when EAs blocks are read immediately before a tape change.
  * Allow compressed dumps to work when -b blocksize setting is the maximum
    a tape drive supports.
  * Remove code added for building on systems other than __linux__
  * Major reworking of how reading from disk and tape works. Dump now
    supports writing a compressed dump to a file and then writing that to
    tape. There is now only one "read" function. We do not have separate
    functions for reading tapes, files, compressed tapes, compressed files.
  * Improve the efficiency of TS_ADDR (and TS_INODE) record for
    representing larger files. A single TS_ADDR record can now represent up
    to 4GB of file rather than just 512K. Dumps written by 0.4b49 cannot be
    restored using 0.4b48 and before.
- 0.4b48 changelog:
  * Handle fs with more than 2^32 blocks (Greg Oster)
  * Handle EA stored in blocks with address >2^32.
  * Handle the case were EAs are stored across two blocks. Fixes several
    reported bugs regarding the restore of directory attributes.
    Additionally, now restore -C passes too. Originally restore -C was
    patched for files, but not directories, in debian bug#940473 by
    Alexander Zangerl.  Substantially redone and extended to directory
    attributes here.
  * Do not record garbage data in dump for files with
    EXT2_EXTENT_FLAGS_UNINIT set indicating that the disk block has not
    been written to and should be assumed to be all zeros.
  * Dump small files on ext4 partitions with -O inline-data set.
  * Major performance enhancements on the restoring and verifying of very
    sparse files.
  * Handle dumps that are over 2^32 (tape) blocks long (>4T)
  * Handle restoring sparse files that start with a hole from dump versions
    0.4b42/43. Previously they were restored but corrupted as some of the
    initial hole was moved to the end.
  * Many cleanups. Move to autoconf v0.71. Remove need to build with
  - fcommon. Build with -W -Wall and without compiler warnings. Add some
    compile time checks for structures that are written to tape and must
    not change.
  * Extensive regression tests. Every bug fixed by 0.4b48 release is now
    covered by a regression test along with testing the restore of a historical
    dump created by the previous versions from 0.4b5 through 0.4b47.
- Use autopatch
- Refresh patches
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Jul 16 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to 0.4b47:
  * Fix missing lzo return (Alexey Svistunov).
  * Fix building with OpenSSL 1.1 (Daniel Molkentin).
  * Fix bashisms in examples (Oleksandr Chumachenko).
  * Use xattrs funcs from the C library (Vaclav Dolezal).
  * Fix date mangling in man pages (Mike Frysinger).
  * Force -fcommon when building (Mike Frysinger).
  * Add error checking to SSL init transformation (Mike Frysinger).
  * Fix restore -C calls with ftruncate (Alexander Zangerl).
  * Restore symlink timestamps (Alexander Zangerl).
- Remove upstreamed patches:
  * dump-0.4b43-fix-bashisms.patch
  * dump-0.4b46-lzo-no-return.patch
  * dump-0.4b46-openssl-1.1.patch
- Run spec-cleaner
* Sun Mar 29 2020 Kristyna Streitova <kstreitova@suse.com>
- starting with GCC 10, the default of '-fcommon' option will
  change to '-fno-common'. Because dump build fails with
  'fno-common', add '-fcommon' option to optflags as a temporary
  workaround for this problem till it's properly fixed [bsc#1160263]
* Thu Jun 15 2017 tchvatal@suse.com
- Add sqlite3 dependency and enable building with it
* Thu Jun 15 2017 daniel.molkentin@suse.com
- Compile with OpenSSL 1.1 (bsc#1042637)
- add patches:
  * dump-0.4b46-openssl-1.1.patch
* Mon Mar 27 2017 mpluskal@suse.com
- Conform to packaging guidelines with update-alternatives
- Clenaup with spec-cleaner
* Tue Mar 21 2017 svalx@svalx.net
- Update to 0.4b44
  * Improve data throughput when using compression in dump by
    allowing multiple slaves to compress in parallel. Thanks
    to Phillip Susi <psusi@cfl.rr.com> for the patch.
  * Add dump encryption support and reorganise the whole
    compression/encryption code as plugins. Thanks to
    Bear Giles <bgiles@coyotesong.com> for the patch.
  * Add sqlite index support and reorganize the QFA code
    as plugins. Thanks to Bear Giles <bgiles@coyotesong.com> for
    the patch.
  * Lots of various build cleanups and minor bugfixes.
  * Use pkg-config to locate openssl dependencies to fix ermt linking.
  * Fix building when QFA code is disabled (Alexander Zangerl).
  * Fix crash with the -Q option (Alexander Zangerl).
  * Fix crash with legacy indexer (Alexander Zangerl).
  * Fix handling of the -A flag.
  * Fix compression enabling logic (Alexander Zangerl).
  * Skip unhandled fstab entries (Josef Ridky).
- Add ermt (1) man page
- A new version of dump have an updated make system, because of this
  * remove patches dump-0.4b43-configure.patch, dump-0.4b43-destdir.patch, dump-buildfix.patch
  * rebase patch dump-0.4b43-pathnames.patch to dump-0.4b46-pathnames.patch
- Add dump-0.4b46-lzo-no-return.patch - fixing rpmlint
  no-return-in-nonvoid-function error in dump
- Add dump-0.4b46-rmt-ermt.patch - independent rmt and ermt build,
  change its locations to _bindir
- Cleanup spec file with spec-cleaner
- Separated rmt subpackage
- Alternatives system for rmt/ermt
* Fri May  1 2015 mpluskal@suse.com
- Enable ermt support
- Update dependencies
* Tue Feb 24 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Update urls
- Add patch dump-buildfix.patch
- Update to 0.4b44
  * Recognize ext4 partitions in dump -w commands (Sourceforge bug
    [#3125587], RedHat bug #658890).
  * Fix an issue with multi volume backups, which breaks restoring
    of files which are splitted on two or more volumes and are
    starting on 2nd tape or later (RedHat bug #507948).
  * Fix a bug in dump when dumping files with holes. This bug was
    introduced in 0.4b42 while adding ext4 support. (Sourceforge
    bug #3133762).
  * Fix a bug in restore -P where useless index files for
    compressed dumps were created (Debian bug #583093).
  * Fix SYS_clone invocation on s390 architectures (Sourceforge
    bug #3303235).
  * Fix static builds.
  * Add quick regression script from Bear Giles.
  * Fix a bug introduced in 0.4b43 causing restore to crash when
    asking for a new volume when doing multi-volume restores.
* Sun Nov 16 2014 Led <ledest@gmail.com>
- fix bashisms in example scripts
- add patches:
  * dump-0.4b43-fix-bashisms.patch
* Sat Jan 12 2013 coolo@suse.com
- remove suse_update_config
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Thu Sep 30 2010 nadvornik@suse.cz
- updated to 0.4b43
  * ext4 support
  * selinux improvements
  * bugfixes, see CHANGES file
* Sat Mar 31 2007 rguenther@suse.de
- add zlib-devel BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
* Tue Jan  3 2006 nadvornik@suse.cz
- updated to 0.4b41
  * ACL fixes
* Mon Jul 25 2005 nadvornik@suse.cz
- do not install rmt
* Fri Jul 15 2005 nadvornik@suse.cz
- updated to 0.4b40
  * support for extended attributes (ACL)
* Tue Apr 19 2005 nadvornik@suse.de
- fixed including of linux/fs.h
* Tue Jan 25 2005 nadvornik@suse.cz
- updated to 0.4b39
* Wed Sep  1 2004 nadvornik@suse.cz
- updated to 0.4b37
* Tue Jun  1 2004 ro@suse.de
- avoid inclusion of linux/audit.h
* Tue Feb 10 2004 kukuk@suse.de
- Fix compiling on 64bit architectures
* Thu Feb  5 2004 nadvornik@suse.cz
- updated to 0.4b35
* Fri Aug  1 2003 nadvornik@suse.cz
- fixed to compile on x86_64
* Wed Jul 23 2003 nadvornik@suse.cz
- update to 0.4b34, fixes [#27810]
* Mon Feb 17 2003 nadvornik@suse.cz
- updated to 0.4b33
* Thu Aug 29 2002 nadvornik@suse.cz
- updated to 0.4b31:
  - fixed rmt open flags transmission (remote dump was broken in 0.4b29)
  - fixed the tape length calculation when using large tapes and compression
  - made dump save 32 bit UID/GID
* Tue Jul  2 2002 nadvornik@suse.cz
- updated to 0.4b29
  - bugfixes
  - more examples
* Thu Apr 18 2002 nadvornik@suse.cz
- updated to 0.4b28
  - bugfixes
  - do not include kernel haders
- compiled with readline
* Tue Apr  2 2002 nadvornik@suse.cz
- fixed to compile with new autoconf
* Wed Jan 30 2002 nadvornik@suse.cz
- update to 0.4b26:
  - more examples
  - bugfixes
* Mon Jan  7 2002 nadvornik@suse.cz
- added link /etc/rmt -> /sbin/rmt for compatibility [bug #12615]
* Thu Nov 22 2001 nadvornik@suse.cz
- update to 0.4b25:
  - more documentation
  - added bzip2 compression
  - suport for backups to CD
  - bugfixes
* Fri Aug 17 2001 nadvornik@suse.cz
- added fix for traverse.c
* Wed Aug 15 2001 ro@suse.de
- up to 0.4b23 to make it build with new e2fsprogs
* Tue Feb 27 2001 nadvornik@suse.cz
- update to 0.4b21
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Thu Feb 22 2001 schwab@suse.de
- Fix missing includes.
- Replace ino_t by __ino_t instead of unsigned int.
- Don't kill entire process group on crash.
* Fri Feb  9 2001 uli@suse.de
- fixed for glibc 2.2.1
* Thu Jan 11 2001 nadvornik@suse.cz
- added lfs patch
* Tue Dec  5 2000 smid@suse.cz
- path to rmt changed [#4306]
* Sun Dec  3 2000 smid@suse.cz
- new version 0.4b20
* Wed Nov  8 2000 ro@suse.de
- fixed neededforbuild
* Fri Sep 29 2000 smid@suse.cz
- new version 0.4b19
* Fri Apr  7 2000 smid@suse.cz
- upgrade to 0.4b16
- buildroot added
* Thu Mar  2 2000 kukuk@suse.de
- Update to version 0.4b15 and correct security fix
* Thu Feb 10 2000 kukuk@suse.de
- Update to version 0.4b14
* Sun Jan 30 2000 kukuk@suse.de
- Update to version 0.4b13
- Move /usr/man -> /usr/share/man
* Mon Dec  6 1999 kukuk@suse.de
- Update to version 0.4b11 (BUG #1448)
- Fix dump manual page (BUG #1367)
* Sat Nov 13 1999 kukuk@suse.de
- Compile without ext2fs progs, but use ext2fs development package
* Mon Nov  8 1999 kukuk@suse.de
- Security update for dump to 0.4b9
* Fri Oct 29 1999 ro@suse.de
- fixed spec for e2fsprogs-1.17
* Sun Oct 24 1999 ro@suse.de
- fixed spec for e2fsprogs-1.16
* Mon Oct 18 1999 kukuk@suse.de
- Update to version 0.4b7
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Aug 31 1999 ro@suse.de
- changed for e2fsprogs-1.15 / only do install-lib
* Sat Jun 26 1999 kukuk@suse.de
- Update to dump 0.4b4
* Tue Sep  1 1998 ro@suse.de
- use e2fsprgs-1.12-sources / dont use -lbsd
* Mon Oct 20 1997 ro@suse.de
- ready for autobuild
  minor patch in dump/traverse.c
* Thu Jan  2 1997 florian@suse.de
- recompile to use newer and static ext2 libraries
